@@ -26,12 +26,16 @@
 (********** Core Module: hand-written class definitions **********)
 
 class domString (obj : TDOMString.t) =
- object
+ object (self)
   method as_DOMString = (obj :> TDOMString.t)
   method to_string = IDOMString.to_string obj
+  method equals (o2 : domString) = IDOMString.equals obj o2#as_DOMString
  end
 ;;
 
+let gdome_obj_eq o1 o2 = o1#equals o2;;
+let (===) = gdome_obj_eq;;
+
 class domImplementation obj =
  object
   method hasFeature ~feature ~version = IDOMImplementation.hasFeature ~this:obj ~feature:((feature : domString)#as_DOMString) ~version:((version : domString)#as_DOMString)
@@ -41,6 +45,11 @@ class domImplementation obj =
   method createDocumentFromMemory ~doc ?validatingMode ?keepEntities () = new document (IDOMImplementation.createDocumentFromMemory ~this:obj ~doc:((doc : domString)#as_DOMString) ?validatingMode ?keepEntities ())
   method saveDocumentToFile ~(doc : document) =
    IDOMImplementation.saveDocumentToFile ~this:obj ~doc:((doc : document)#as_Document)
+ method saveDocumentToMemory ~(doc : document) =
+  IDOMImplementation.saveDocumentToMemory ~this:obj ~doc:((doc : document)#as_Document)
+ method enableEvent ~doc ~name = IDOMImplementation.enableEvent ~this:obj ~doc:((doc : document)#as_Document) ~name
+ method disableEvent ~doc ~name = IDOMImplementation.disableEvent ~this:obj ~doc:((doc : document)#as_Document) ~name
+ method eventIsEnabled ~doc ~name = IDOMImplementation.eventIsEnabled ~this:obj ~doc:((doc : document)#as_Document) ~name
  end
 
 (********** Events Module: generated class definitions **********)
@@ -73,10 +82,10 @@ and mutationEvent (obj : TMutationEvent.t) =
  object
   inherit (event (obj :> TEvent.t))
   method as_MutationEvent = obj
-  method get_relatedNode = let obj = IMutationEvent.get_relatedNode ~this:obj in new node obj
-  method get_prevValue = let obj = IMutationEvent.get_prevValue ~this:obj in new domString obj
-  method get_newValue = let obj = IMutationEvent.get_newValue ~this:obj in new domString obj
-  method get_attrName = let obj = IMutationEvent.get_attrName ~this:obj in new domString obj
+  method get_relatedNode = let obj = IMutationEvent.get_relatedNode ~this:obj in match obj with None -> None | Some obj -> Some (new node obj)
+  method get_prevValue = let obj = IMutationEvent.get_prevValue ~this:obj in match obj with None -> None | Some obj -> Some (new domString obj)
+  method get_newValue = let obj = IMutationEvent.get_newValue ~this:obj in match obj with None -> None | Some obj -> Some (new domString obj)
+  method get_attrName = let obj = IMutationEvent.get_attrName ~this:obj in match obj with None -> None | Some obj -> Some (new domString obj)
   method get_attrChange = IMutationEvent.get_attrChange ~this:obj
   method initMutationEvent ~typeArg ~canBubbleArg ~cancelableArg ~relatedNodeArg ~prevValueArg ~newValueArg ~attrNameArg ~attrChangeArg = IMutationEvent.initMutationEvent ~this:obj  ~typeArg:((typeArg : domString)#as_DOMString) ~canBubbleArg ~cancelableArg ~relatedNodeArg:(match relatedNodeArg with None -> None | Some relatedNodeArg -> Some (relatedNodeArg : node)#as_Node) ~prevValueArg:(match prevValueArg with None -> None | Some prevValueArg -> Some (prevValueArg : domString)#as_DOMString) ~newValueArg:(match newValueArg with None -> None | Some newValueArg -> Some (newValueArg : domString)#as_DOMString) ~attrNameArg:(match attrNameArg with None -> None | Some attrNameArg -> Some (attrNameArg : domString)#as_DOMString) ~attrChangeArg
  end
@@ -111,6 +120,9 @@ and node (obj : TNode.t) =
   method get_prefix = let obj = INode.get_prefix ~this:obj in match obj with None -> None | Some obj -> Some (new domString obj)
   method set_prefix ~value = INode.set_prefix ~this:obj ~value:(match value with None -> None | Some value -> Some (value : domString)#as_DOMString)
   method get_localName = let obj = INode.get_localName ~this:obj in match obj with None -> None | Some obj -> Some (new domString obj)
+
+  method isSameNode other = INode.isSameNode ~this:obj ((other : node)#as_Node)
+  method equals other = INode.isSameNode ~this:obj ((other : node)#as_Node)
   method insertBefore ~newChild ~refChild = let obj = INode.insertBefore ~this:obj  ~newChild:((newChild : node)#as_Node) ~refChild:(match refChild with None -> None | Some refChild -> Some (refChild : node)#as_Node) in new node obj
   method replaceChild ~newChild ~oldChild = let obj = INode.replaceChild ~this:obj  ~newChild:((newChild : node)#as_Node) ~oldChild:((oldChild : node)#as_Node) in new node obj
   method removeChild ~oldChild = let obj = INode.removeChild ~this:obj  ~oldChild:((oldChild : node)#as_Node) in new node obj
